@@ -774,8 +774,8 @@ class FakeSessionClient(base_client.SessionClient):
 
     none_actions = ['revertResize', 'os-stop', 'os-start',
                     'forceDelete', 'restore', 'pause', 'unpause', 'unlock',
-                    'unrescue', 'resume', 'suspend', 'lock', 'shelve',
-                    'shelveOffload', 'unshelve', 'resetNetwork']
+                    'unrescue', 'resume', 'suspend', 'shelve',
+                    'shelveOffload', 'resetNetwork']
     type_actions = ['os-getVNCConsole', 'os-getSPICEConsole',
                     'os-getRDPConsole']
 
@@ -836,6 +836,32 @@ class FakeSessionClient(base_client.SessionClient):
                     # host can be optional
                     expected.add('host')
                 assert set(body[action].keys()) == expected
+        elif action == 'lock':
+            if self.api_version < api_versions.APIVersion("2.73"):
+                assert body[action] is None
+            else:
+                # In 2.73 and above, we allow body to be one of these:
+                # a) {'lock': None}
+                # b) {'lock': {}}
+                # c) {'lock': {locked_reason': 'blah'}}
+                if body[action] is not None:
+                    expected = set()
+                    if 'locked_reason' in body[action].keys():
+                        # reason can be optional
+                        expected.add('locked_reason')
+                    assert set(body[action].keys()) == expected
+                else:
+                    assert body[action] is None
+        elif action == 'unshelve':
+            if self.api_version < api_versions.APIVersion("2.77"):
+                assert body[action] is None
+            else:
+                # In 2.77 and above, we allow body to be one of these:
+                # {'unshelve': None}
+                # {'unshelve': {'availability_zone': 'foo-az'}}
+                if body[action] is not None:
+                    assert set(body[action].keys()) == set(
+                        ['availability_zone'])
         elif action == 'rebuild':
             body = body[action]
             adminPass = body.get('adminPass', 'randompassword')
